@@ -15,6 +15,10 @@ DLLEXPORT void xml6_node_add_reference(xmlNodePtr self) {
 DLLEXPORT int xml6_node_remove_reference(xmlNodePtr self) {
     assert(self != NULL);
     assert(self->type != XML_NAMESPACE_DECL);
+    if (self->_private == NULL) {
+        /* unexpected; print some extra debugging */
+        fprintf(stderr, __FILE__ ":%d %p type=%d name='%s'\n", __LINE__, self, self->type, (self->name ? (char*) self->name : "(null)"));
+    }
     return xml6_ref_remove( &(self->_private), "node", (void*) self);
 }
 
